Enum Operation
Source pub enum Operation<'a> {
Read(&'a mut [u8]),
Write(&'a [u8]),
}
I2C operation.
Several operations can be combined as part of a transaction.
Read data into the provided buffer.
Write data from the provided buffer.
Formats the value using the given formatter.
Read more
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
[From]<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.